import * as Realm from 'realm';
import { Service } from '../../service';
import { HttpRequest, HttpMethod, HttpResponse } from '../../http';
export interface AuthenticationResponse {
    userId: string;
    isAdmin: boolean;
    created: boolean;
    authToken?: string;
}
export interface DeprecatedAuthenticationResponse extends AuthenticationResponse {
    refresh_token: {
        token: string;
        token_data: {
            identity: string;
            is_admin: boolean;
            app_id?: string;
            access: ["refresh"];
            expires: number;
        };
    };
}
export declare type AuthUserMetadata = {
    [key: string]: string;
};
export declare type AuthUser = {
    userId: string;
    isAdmin: boolean;
    metadata?: AuthUserMetadata;
};
export declare class AuthService extends Service {
    tokenPrivateKey: string;
    realm: Realm;
    readonly baseHttpEndpoint: string;
    readonly httpEndpoints: {
        route: string;
        method: HttpMethod;
        handler: any;
    }[];
    authenticateOrCreateUser(body: any): Promise<AuthenticationResponse>;
    start(): Promise<void>;
    authenticate(request: HttpRequest): Promise<AuthenticationResponse>;
    authenticateDeprecated(request: HttpRequest): Promise<DeprecatedAuthenticationResponse | HttpResponse>;
    getUser(userId: string): AuthUser;
    getUserMetadata(userId: string): AuthUserMetadata;
    storeUser(userId: string, isAdmin: boolean, metadata?: {
        [key: string]: string;
    }): AuthUser;
    retrieveUser(userId: string): AuthUser;
}
