"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Realm = require("realm");
const shared_1 = require("../../shared");
const fs = require("fs");
const service_1 = require("../../service");
let RealmFileSchema = {
    name: 'realm_file',
    primaryKey: 'path',
    properties: {
        path: 'string',
        creatorId: 'string',
        creationDate: 'date'
    }
};
const ACCESS_LEVEL_NONE = 0;
const ACCESS_LEVEL_READ = 1;
const ACCESS_LEVEL_WRITE = 2;
const ACCESS_LEVEL_ADMIN = 3;
const PERMISSION_TYPE_ALL = 0;
const PERMISSION_TYPE_EXACT = 1;
const PERMISSION_TYPE_REGEX = 2;
let PermissionConditionSchema = {
    name: 'permission_condition',
    properties: {
        path: 'string',
        key: 'string',
        value: 'string',
        permission_type: 'int',
        access_level: 'int'
    }
};
class RealmManagementService extends service_1.Service {
    get baseHttpEndpoint() { return 'realms'; }
    get httpEndpoints() {
        return [
            { route: '/access-token', method: 'post', handler: this.accessToken.bind(this) },
            { route: '/', method: 'get', handler: this.get.bind(this) },
        ];
    }
    accessToken(incomingRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            let path = incomingRequest.body.path;
            if (path === undefined)
                throw new Error('No path present when requesting Realm access');
            if (!incomingRequest.body.data)
                throw new Error('No auth token present when requesting Realm access');
            const userId = shared_1.parseTokenFromBase64RSA_SHA256(incomingRequest.body.data)["user_id"];
            const appId = incomingRequest.body["app_id"] || "io.realm.Auth";
            const expires = Math.round(Date.now() / 1000) + 600;
            const token_data = {
                identity: userId,
                appId: appId,
                access: ['download', 'upload', 'manage'],
                path: path,
                timestamp: Date.now() / 1000,
                expires: expires
            };
            let token = shared_1.signToken(token_data, this.tokenKey);
            if (!this.realm.objectForPrimaryKey('realm_file', path)) {
                this.realm.write(() => {
                    this.realm.create('realm_file', { path: path, creatorId: userId, creationDate: new Date() });
                });
            }
            return {
                access_token: {
                    token: token,
                    token_data: token_data
                }
            };
        });
    }
    get(incomingRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.realm.objects('realm_file').slice();
        });
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            this.realm = new Realm({
                path: './data/realmmanagement.realm',
                schema: [RealmFileSchema, PermissionConditionSchema]
            });
            this.tokenKey = yield new Promise((resolve, reject) => {
                fs.readFile('./keys/auth.key', (err, data) => {
                    if (err) {
                        reject(err);
                    }
                    else {
                        resolve(data.toString());
                    }
                });
            });
        });
    }
}
exports.RealmManagementService = RealmManagementService;
//# sourceMappingURL=realmmanagementservice.js.map