"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const portfinder = require("portfinder");
const service_1 = require("../../service");
const realm_sync_server_1 = require("realm-sync-server");
function DefaultSyncServiceConfiguration() {
    return {
        hostname: '127.0.0.1',
        port: 0,
        dataPath: './data',
        publicKeyPath: './keys/auth.pub'
    };
}
exports.DefaultSyncServiceConfiguration = DefaultSyncServiceConfiguration;
class SyncService extends service_1.Service {
    constructor(config) {
        super(config);
        config = Object.assign(DefaultSyncServiceConfiguration(), config);
        if (typeof config.port !== 'number') {
            try {
                config.port = parseInt(config.port);
            }
            catch (error) {
                throw new Error('The port must be a valid number format.');
            }
        }
        this.config = config;
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            this.config.port = (this.config.port === 0 || this.config.port == null) ? yield portfinder.getPortPromise() : this.config.port;
            this.syncServer = new realm_sync_server_1.RealmSyncServer({
                dataPath: this.config.dataPath,
                publicKeyPath: this.config.publicKeyPath,
                listenAddress: this.config.hostname,
                listenPort: this.config.port,
                logCallback: (eventCode, message) => {
                    console.log(`${this.constructor.name}:${eventCode}:${message}`);
                }
            });
            this.websocketEndpoint = `ws://${this.config.hostname}:${this.config.port}`;
            yield this.syncServer.start();
        });
    }
    stop() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.syncServer.stop();
        });
    }
}
exports.SyncService = SyncService;
//# sourceMappingURL=syncservice.js.map