"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Mixpanel = require("mixpanel");
const fs = require("fs-extra");
const path = require("path");
const promptly = require("promptly");
const mixpanel = Mixpanel.init('953cbc7bc5e8daa02b91425ac92d36dd');
const DEFAULT_PATH = path.join(process.cwd(), 'realm-object-server-agreement.json');
function writeAgreementJsonToProcessWorkingDirectory(name, email, includeTimestamp) {
    return __awaiter(this, void 0, void 0, function* () {
        const json = {
            email: email,
            name: name
        };
        if (includeTimestamp) {
            json["timestamp"] = Date.now();
        }
        yield fs.writeFile(DEFAULT_PATH, JSON.stringify(json), { encoding: 'utf8' });
    });
}
function attemptToSubmitToMixpanel(name, email, method) {
    return __awaiter(this, void 0, void 0, function* () {
        const json = require(DEFAULT_PATH);
        if (json["timestamp"]) {
            return;
        }
        yield writeAgreementJsonToProcessWorkingDirectory(name, email, true);
        mixpanel.track('ros_agreed_to_terms', {
            version: (yield fs.readJson(path.join(__dirname, '../package.json'))).version,
            name: name,
            email: email,
            method: method
        });
    });
}
function termsOfService(config) {
    return __awaiter(this, void 0, void 0, function* () {
        if (typeof config.agreement === 'object') {
            if (!config.agreement["name"] || !config.agreement["email"]) {
                throw new Error('Please supply both an email and a name.');
            }
            const email = config.agreement["email"];
            const name = config.agreement["name"];
            yield writeAgreementJsonToProcessWorkingDirectory(email, name, false);
            yield attemptToSubmitToMixpanel(name, email, 'in memory json');
            return;
        }
        if (typeof config.agreement === 'string') {
            const expectedAgreementJSONLocation = config.agreement;
            const isAgreementJSONExists = yield fs.pathExists(expectedAgreementJSONLocation);
            if (!isAgreementJSONExists) {
                throw new Error(`The custom path of your agreement json at ${expectedAgreementJSONLocation} wasn't found.
            Please supply a correct absolute path that exists.`);
            }
            const agreementJSON = yield fs.readJson(expectedAgreementJSONLocation);
            yield writeAgreementJsonToProcessWorkingDirectory(agreementJSON.name, agreementJSON.email, false);
            yield attemptToSubmitToMixpanel(agreementJSON.name, agreementJSON.email, 'from custom agreement json file');
            return;
        }
        const isAgreementJSONExists = yield fs.pathExists(DEFAULT_PATH);
        if (isAgreementJSONExists) {
            const agreementJSON = yield fs.readJson(DEFAULT_PATH);
            yield attemptToSubmitToMixpanel(agreementJSON.name, agreementJSON.email, 'from default agreement json file');
            return;
        }
        console.log('Please agree to the Realm Object Server terms of services with your name and email.');
        const name = yield promptly.prompt('Your name: ');
        const email = yield promptly.prompt('Your email: ');
        console.log('Enjoy Realm Object Server (^_^)');
        yield writeAgreementJsonToProcessWorkingDirectory(name, email, false);
        yield attemptToSubmitToMixpanel(name, email, 'from command prompt');
    });
}
exports.termsOfService = termsOfService;
//# sourceMappingURL=termsofservice.js.map