"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const _1 = require("../");
const Realm = require("realm");
const fs = require("fs-extra");
const del = require("del");
const faker = require("faker");
describe('Test Realm-JS integration', function () {
    const PORT = 5678;
    const HOST = 'localhost';
    const REALM_JS_ACCESS_TOKEN = 'eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJOb3RpZmllciI6dHJ1ZSwiU3luYyI6dHJ1ZSwiaWF0IjoxNDkyNjExMzEzfQ.Yb-o622ZYLKCQ0kTEDpBm6FsG68X9nj-OCdD4dT1G5W10fjhsTdUJiR1uYBilZPqgZEmIdDgd59rDpEjnqDhBCjTzpbsMVBGQrHj3B5eW4oGvxDkdqjR_fjwc5-zH3BeXMd9UAj13bLrxLsM0_g1FXIjmXCOK7YBrL0kKYAI2IVjqAGsI8zThhmbqxDvBeD8TVPc-brBZvXXHPO63ierJevjtZRz7mg_oV-B13gXXIxy2jlnevqFyBVRF6cd3bJmIpLUXHecQXqDGDeLaVlo2NDcnxl5OoVBN1QUSxptgQc-FIq-5qtxZXHooIJUpKQwtD2mBkJ-HBpxWbQR2C90UA';
    Realm.Sync.setAccessToken(REALM_JS_ACCESS_TOKEN);
    const ProductSchema = {
        name: 'Product',
        primaryKey: 'productId',
        properties: {
            productId: { type: 'int', optional: false },
            name: { type: 'string', optional: false },
            price: { type: 'float', optional: false }
        }
    };
    let server;
    before(() => __awaiter(this, void 0, void 0, function* () {
        yield del(['./data']);
        Realm.clearTestState();
        server = new _1.Server({
            port: PORT
        });
        yield server.start();
    }));
    it('should be able to register to realm-js', function (done) {
        Realm.Sync.User.register(`http://${HOST}:${PORT}`, 'sampleuser', 'samplepassword', (err, user) => {
            if (err) {
                done(err);
            }
            else {
                chai_1.expect(user).to.not.be.null;
                done();
            }
        });
    });
    it('should be able to login to realm-js', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const registeredUser = yield new Promise((resolve, reject) => {
                Realm.Sync.User.register(`http://${HOST}:${PORT}`, 'newuser', 'samplepassword', (err, user) => {
                    if (err) {
                        reject(err);
                    }
                    else {
                        resolve(user);
                    }
                });
            });
            registeredUser.logout();
            const loggedInUser = yield new Promise((resolve, reject) => {
                Realm.Sync.User.login(`http://${HOST}:${PORT}`, 'newuser', 'samplepassword', (err, user) => {
                    if (err) {
                        reject(err);
                    }
                    else {
                        resolve(user);
                    }
                });
            });
        });
    });
    it('should create error when trying to login with an unknown username', function (done) {
        Realm.Sync.User.login(`http://${HOST}:${PORT}`, 'sameuser', 'samplepassword', (err, user) => {
            chai_1.expect(err).not.to.not.be.undefined;
            done();
        });
    });
    it('should create error when trying to register an existing username', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const registeredUser = yield new Promise((resolve, reject) => {
                Realm.Sync.User.register(`http://${HOST}:${PORT}`, 'sameuser', 'samplepassword', (err, user) => {
                    if (err) {
                        reject(err);
                    }
                    else {
                        resolve(user);
                    }
                });
            });
            registeredUser.logout();
            try {
                const registeredUserAgain = yield new Promise((resolve, reject) => {
                    Realm.Sync.User.register(`http://${HOST}:${PORT}`, 'sameuser', 'samplepassword', (err, user) => {
                        if (err) {
                            reject(err);
                        }
                        else {
                            resolve(user);
                        }
                    });
                });
            }
            catch (err) {
                chai_1.expect(err).to.not.be.undefined;
            }
        });
    });
    it('should be able to write to a realm', (done) => {
        const username = `sampleuser`;
        Realm.Sync.User.login(`http://${HOST}:${PORT}`, username, 'samplepassword', (err, user) => {
            if (err) {
                done(err);
                return;
            }
            chai_1.expect(user).not.to.be.null;
            chai_1.expect(user).not.to.be.undefined;
            const realm = new Realm({
                sync: {
                    url: `realm://${HOST}:${PORT}/product`,
                    user: user
                },
                schema: [ProductSchema]
            });
            realm.write(() => {
                for (let index = 0; index < 100; index++) {
                    realm.create('Product', {
                        productId: 0,
                        name: faker.commerce.productName(),
                        price: faker.random.number({ min: 12, max: 7000 })
                    }, true);
                }
            });
            fs.exists(`./realm-object-server/sampleuser/realm%3A%2F%2F${HOST}%3A${PORT}%2Fproduct`, (exists) => {
                chai_1.expect(exists).to.be.true;
                done();
            });
        });
    });
    after(() => __awaiter(this, void 0, void 0, function* () {
        yield server.shutdown();
        yield del(['./data']);
    }));
});
//# sourceMappingURL=realmjs-integration-tests.spec.js.map