"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require("../");
const Realm = require("realm");
const del = require("del");
const path = require("path");
const fs = require("fs");
describe('Tests for Server agreement', function () {
    const tmpDir = path.join(__dirname, './tmp');
    const customAgreementJSONPath = path.join(tmpDir, 'custom-realm-object-server-agreement.json');
    before(() => __awaiter(this, void 0, void 0, function* () {
        Realm.Sync.setLogLevel('error');
        yield del(['./data']);
        Realm.clearTestState();
        const tmpDirExists = yield new Promise((resolve, reject) => {
            fs.exists(tmpDir, resolve);
        });
        if (tmpDirExists) {
            return;
        }
        yield new Promise((resolve, reject) => {
            fs.mkdir(tmpDir, (err) => {
                if (err) {
                    reject;
                }
                else
                    resolve();
            });
        });
    }));
    after(() => __awaiter(this, void 0, void 0, function* () {
        yield del(['./data', tmpDir]);
    }));
    it('should start successfully when providing json agreement', function () {
        return __awaiter(this, void 0, void 0, function* () {
            let server = new _1.Server({
                agreement: {
                    name: 'Joe Test',
                    email: 'realm@realm.io'
                }
            });
            yield server.start();
            yield server.shutdown();
        });
    });
    it('should start successfully when providing custom path agreement', function () {
        return __awaiter(this, void 0, void 0, function* () {
            yield new Promise((resolve, reject) => {
                const jsonString = JSON.stringify({ name: 'test user', email: 'test@realm.io' });
                fs.writeFile(customAgreementJSONPath, jsonString, 'utf8', (err) => {
                    if (err) {
                        reject(err);
                    }
                    else {
                        resolve();
                    }
                });
            });
            let server = new _1.Server({
                agreement: customAgreementJSONPath
            });
            yield server.start();
            yield server.shutdown();
        });
    });
});
//# sourceMappingURL=server-agreement.spec.js.map