"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const _1 = require("../");
const del = require("del");
class TestService extends _1.Service {
    constructor(baseEndpoint) {
        super({});
        this.baseEndpoint = baseEndpoint;
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            this.started = true;
        });
    }
    get baseHttpEndpoint() { return this.baseEndpoint; }
    get httpEndpoints() { return []; }
}
describe('Test serverStarted event', function () {
    beforeEach(() => __awaiter(this, void 0, void 0, function* () {
        Realm.clearTestState();
        yield del(['./data']);
    }));
    afterEach(() => __awaiter(this, void 0, void 0, function* () {
        Realm.clearTestState();
        yield del(['./data']);
    }));
    it('should only start once', function () {
        return __awaiter(this, void 0, void 0, function* () {
            let server = new _1.Server();
            yield server.start();
            const err = yield server.start().then(null, err => {
                return err;
            });
            chai_1.expect(err.message).to.contain("already been started");
            yield server.shutdown();
        });
    });
    it('should emit event on startup', function () {
        return __awaiter(this, void 0, void 0, function* () {
            let server = new _1.Server();
            let eventTriggered = false;
            server.on('serverStarted', (serverObject) => {
                chai_1.expect(serverObject).to.equal(server);
                eventTriggered = true;
            });
            yield server.start();
            chai_1.expect(eventTriggered).to.be.true;
            yield server.shutdown();
        });
    });
    it('should start by default with usernamePassword and realmManagement services', function () {
        return __awaiter(this, void 0, void 0, function* () {
            let server = new _1.Server();
            let eventTriggered = false;
            server.on('serverStarted', (serverObject) => {
                chai_1.expect(serverObject).to.equal(server);
                eventTriggered = true;
            });
            yield server.start();
            chai_1.expect(server.services.length).to.be.eq(3);
            chai_1.expect(server.services.find(service => service.name === 'UsernamePasswordAuthService')).to.be.a('object');
            chai_1.expect(server.services.find(service => service.name === 'RealmManagementService')).to.be.a('object');
            chai_1.expect(server.services.find(service => service.name === 'SyncService')).to.be.a('object');
            yield server.shutdown();
        });
    });
    it('should start only with services specifed in the config', function () {
        return __awaiter(this, void 0, void 0, function* () {
            let server = new _1.Server({ services: { UsernamePasswordAuthService: {} } });
            let eventTriggered = false;
            server.on('serverStarted', (serverObject) => {
                chai_1.expect(serverObject).to.equal(server);
                eventTriggered = true;
            });
            yield server.start();
            chai_1.expect(server.services.length).to.be.eq(1);
            chai_1.expect(server.services.find(service => service.name === 'UsernamePasswordAuthService')).to.be.a('object');
            yield server.shutdown();
        });
    });
    it('should call start on all service', function () {
        return __awaiter(this, void 0, void 0, function* () {
            let server = new _1.Server({ services: { UsernamePasswordAuthService: {} } });
            let eventTriggered = false;
            yield server.addService(new TestService('endpoint'), {});
            yield server.start();
            chai_1.expect(server.services.length).to.be.eq(2);
            for (let service of server.services) {
                if (service.name === 'TestService')
                    chai_1.expect(service.started).to.be.true;
                else if (service.name === 'UsernamePasswordAuthService')
                    chai_1.expect(service.realm).to.be.an.instanceOf(Realm);
                else
                    chai_1.expect.fail();
            }
            yield server.shutdown();
        });
    });
    it('should ensure services use unique endpoints', function () {
        return __awaiter(this, void 0, void 0, function* () {
            let server = new _1.Server();
            yield server.addService(new TestService('duplicateendpoint'), {});
            let exception;
            try {
                yield server.addService(new TestService('duplicateendpoint'), {});
            }
            catch (e) {
                exception = e;
            }
            chai_1.expect(exception).to.be.a('Error');
        });
    });
    it('should ensure baseEndpint is an alphanumeric string', function () {
        return __awaiter(this, void 0, void 0, function* () {
            let server = new _1.Server();
            yield server.addService(new TestService('abc_123'), {});
            let exception;
            try {
                yield server.addService(new TestService('/not alphanumeric'), {});
            }
            catch (e) {
                exception = e;
            }
            chai_1.expect(exception).to.be.a('Error');
        });
    });
});
//# sourceMappingURL=server.spec.js.map