"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const _1 = require("../../");
const superagent = require("superagent");
const Realm = require("realm");
const uuid = require("uuid");
describe('RealmManagement Service Tests', function () {
    let server;
    let username = `Manny${uuid.v4()}`;
    let password = `bat${uuid.v4()}`;
    let userToken;
    let realmManagementService;
    const REALM_JS_ACCESS_TOKEN = 'eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJOb3RpZmllciI6dHJ1ZSwiU3luYyI6dHJ1ZSwiaWF0IjoxNDkyNjExMzEzfQ.Yb-o622ZYLKCQ0kTEDpBm6FsG68X9nj-OCdD4dT1G5W10fjhsTdUJiR1uYBilZPqgZEmIdDgd59rDpEjnqDhBCjTzpbsMVBGQrHj3B5eW4oGvxDkdqjR_fjwc5-zH3BeXMd9UAj13bLrxLsM0_g1FXIjmXCOK7YBrL0kKYAI2IVjqAGsI8zThhmbqxDvBeD8TVPc-brBZvXXHPO63ierJevjtZRz7mg_oV-B13gXXIxy2jlnevqFyBVRF6cd3bJmIpLUXHecQXqDGDeLaVlo2NDcnxl5OoVBN1QUSxptgQc-FIq-5qtxZXHooIJUpKQwtD2mBkJ-HBpxWbQR2C90UA';
    before(function () {
        return __awaiter(this, void 0, void 0, function* () {
            Realm.Sync.setAccessToken(REALM_JS_ACCESS_TOKEN);
            yield Realm.clearTestState();
            server = new _1.Server();
            yield server.start();
            realmManagementService = (yield server.discovery.find('RealmManagementService'));
            let userResponse = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ username: username, password: password, register: true });
            userToken = userResponse.body.refresh_token.token;
        });
    });
    after(function () {
        return __awaiter(this, void 0, void 0, function* () {
            if (server) {
                yield server.shutdown();
            }
        });
    });
    it('DEPRECATED registers realms when getting an access token', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const realmAccessTokenResponse = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ path: '/myrealm', data: userToken });
            chai_1.expect(realmAccessTokenResponse.body.access_token.token).to.be.a('string');
            chai_1.expect(realmManagementService.realm.objects('realm_file').length).to.be.eq(1);
        });
    });
    it('get endpoint returns all realms', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const realmAccessTokenResponse = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ path: '/myrealm', data: userToken });
            chai_1.expect(realmAccessTokenResponse.body.access_token.token).to.be.a('string');
            const response = yield superagent
                .get('http://localhost:9080/realms/');
            chai_1.expect(response.body).to.be.a('array');
            let realms = response.body;
            chai_1.expect(realms.length).to.eq(1);
            chai_1.expect(realms[0].path).to.eq('/myrealm');
            chai_1.expect(realms[0].creatorId).to.eq(username);
            chai_1.expect(realms[0].creationDate).to.be.a('string');
            chai_1.expect(Date.now() - (new Date(realms[0].creationDate)).getTime()).to.be.lessThan(1000);
        });
    });
});
//# sourceMappingURL=realmmanagement.spec.js.map