"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const _1 = require("../../");
const del = require("del");
const superagent = require("superagent");
const Realm = require("realm");
const uuid = require("uuid");
describe('Test UsernamePasswordAuthService', function () {
    let server;
    before(() => __awaiter(this, void 0, void 0, function* () {
        Realm.clearTestState();
        yield del(['./data']);
        server = new _1.Server({
            services: {
                UsernamePasswordAuthService: {},
                RealmManagementService: {}
            }
        });
        yield server.start();
    }));
    after(() => __awaiter(this, void 0, void 0, function* () {
        Realm.clearTestState();
        yield del(['./data']);
        if (server) {
            yield server.shutdown();
        }
    }));
    it('DEPRECATED test user creation', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const username = `Manny${uuid.v4()}`;
            const password = `bat${uuid.v4()}`;
            const response = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ username: username, password: password, register: true });
            chai_1.expect(response.body.created).to.be.true;
            chai_1.expect(response.body.isAdmin).to.be.false;
            chai_1.expect(response.body.userId).to.eq(username);
            chai_1.expect(response.body.authToken).to.be.a('string');
        });
    });
    it('DEPRECATED test existing user authentication', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const username = `Manny${uuid.v4()}`;
            const password = `bat${uuid.v4()}`;
            const createResponse = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ username: username, password: password, register: true });
            chai_1.expect(createResponse.body.created).to.be.true;
            chai_1.expect(createResponse.body.isAdmin).to.be.false;
            chai_1.expect(createResponse.body.userId).to.eq(username);
            chai_1.expect(createResponse.body.authToken).to.be.a('string');
            const loginResponse = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ username: username, password: password });
            chai_1.expect(loginResponse.body.created).to.be.false;
            chai_1.expect(loginResponse.body.isAdmin).to.be.false;
            chai_1.expect(loginResponse.body.userId).to.eq(username);
            chai_1.expect(loginResponse.body.authToken).to.be.a('string');
        });
    });
    xit('DEPRECATED test existing user bad password', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const username = `Manny${uuid.v4()}`;
            const password = `bat${uuid.v4()}`;
            const createResponse = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ username: username, password: password });
            chai_1.expect(createResponse.body.created).to.be.true;
            const loginResponse = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ username: username, password: 'bad password' });
            chai_1.expect(loginResponse.error).to.be.true;
        });
    });
    it('DEPRECATED test get realm refresh token', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const username = `Manny${uuid.v4()}`;
            const password = `bat${uuid.v4()}`;
            const createResponse = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ username: username, password: password, register: true });
            chai_1.expect(createResponse.body.refresh_token.token).to.be.a('string');
            const realmTokenResponse = yield superagent
                .post('http://localhost:9080/auth/')
                .send({ path: '/myrealm', data: createResponse.body.refresh_token.token });
            chai_1.expect(realmTokenResponse.body.access_token.token).to.be.a('string');
        });
    });
    it('should be able to programmatically store and retrieve the same user', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const usernamePasswordService = yield server.discovery.find('UsernamePasswordAuthService');
            usernamePasswordService.storeUser('testuserId', true);
            const foundUser = usernamePasswordService.getUser('testuserId');
            chai_1.expect(foundUser).to.not.be.undefined;
            chai_1.expect(foundUser).to.not.be.null;
            chai_1.expect(foundUser.userId).to.eq('testuserId');
            chai_1.expect(foundUser.isAdmin).to.be.true;
        });
    });
    it('should be able to salt and hash a clear text password', function () {
        return __awaiter(this, void 0, void 0, function* () {
            this.timeout(20000);
            const usernamePasswordService = yield server.discovery.find('UsernamePasswordAuthService');
            const salt = yield usernamePasswordService.createSalt(10000);
            const hash = yield usernamePasswordService.hashPassword('goodpassword', salt);
            const passwordIsSame = yield usernamePasswordService.comparePassword('goodpassword', salt, hash);
            const passwordIsNotSame = yield usernamePasswordService.comparePassword('badpassword', salt, hash);
            chai_1.expect(passwordIsSame).to.be.true;
            chai_1.expect(passwordIsNotSame).to.be.false;
        });
    });
});
//# sourceMappingURL=usernamepasswordauth.spec.js.map