"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const _1 = require("../../");
const del = require("del");
const superagent = require("superagent");
const Realm = require("realm");
describe('Test JSONError http requests', function () {
    const PORT = 5678;
    const HOST = 'localhost';
    const REALM_JS_ACCESS_TOKEN = 'eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJOb3RpZmllciI6dHJ1ZSwiU3luYyI6dHJ1ZSwiaWF0IjoxNDkyNjExMzEzfQ.Yb-o622ZYLKCQ0kTEDpBm6FsG68X9nj-OCdD4dT1G5W10fjhsTdUJiR1uYBilZPqgZEmIdDgd59rDpEjnqDhBCjTzpbsMVBGQrHj3B5eW4oGvxDkdqjR_fjwc5-zH3BeXMd9UAj13bLrxLsM0_g1FXIjmXCOK7YBrL0kKYAI2IVjqAGsI8zThhmbqxDvBeD8TVPc-brBZvXXHPO63ierJevjtZRz7mg_oV-B13gXXIxy2jlnevqFyBVRF6cd3bJmIpLUXHecQXqDGDeLaVlo2NDcnxl5OoVBN1QUSxptgQc-FIq-5qtxZXHooIJUpKQwtD2mBkJ-HBpxWbQR2C90UA';
    class SampleService extends _1.Service {
        constructor() {
            super(...arguments);
            this.shouldReturnJSON = (request) => {
                throw new _1.JSONError({
                    title: 'Oh No'
                });
            };
            this.shouldThrowBubbledException = () => {
                throw new Error('Internal Server Error');
            };
        }
        get baseHttpEndpoint() {
            return 'sample';
        }
        get httpEndpoints() {
            return [{
                    route: '/a', method: 'get', handler: this.shouldReturnJSON,
                },
                {
                    route: '/b', method: 'get', handler: this.shouldThrowBubbledException,
                }];
        }
    }
    let server;
    before(() => __awaiter(this, void 0, void 0, function* () {
        Realm.clearTestState();
        yield del(['./data']);
        Realm.Sync.setAccessToken(REALM_JS_ACCESS_TOKEN);
        server = new _1.Server({
            port: PORT,
            services: {
                UsernamePasswordAuthService: {}
            }
        });
        server.addService(new SampleService(), {});
        yield server.start();
    }));
    after(() => __awaiter(this, void 0, void 0, function* () {
        Realm.clearTestState();
        yield del(['./data']);
        if (server) {
            yield server.shutdown();
        }
    }));
    it('should be able to serialize a JSONError as a 400 bad request', function () {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield superagent.get(`http://${HOST}:${PORT}/sample/a`);
            }
            catch (err) {
                chai_1.expect(err.response.body["code"]).to.eq(400);
                chai_1.expect(err.response.body["title"]).to.eq('Oh No');
            }
        });
    });
    it('should throw an internal server error', function () {
        chai_1.expect(() => __awaiter(this, void 0, void 0, function* () {
            const response = yield superagent.get(`http://${HOST}:${PORT}/sample/b`);
        })).to.throw;
    });
});
//# sourceMappingURL=jsonerror.spec.js.map